/*
 * Kobo Deluxe Sound Effects
 *
 * IF YOU EDIT THIS FILE, YOU WILL NEED
 * TO RECOMPILE THE KOBO DELUXE BINARY!
 */

/* XKobo sfx by Masanao Izumo */
#define	SOUND_BGM	0
#define	SOUND_BUBBLE	1
#define	SOUND_EXPL	2
#define	SOUND_EXPL2	3
#define	SOUND_EXPL3	4
#define	SOUND_ONEUP	5
#define	SOUND_SHOT	6
#define	SOUND_METALLIC	7
#define	SOUND_FINE	8
#define	SOUND_BEAM	9
#define	SOUND_RING	10
#define	SOUND_ENEMYM	11
#define	SOUND_BOMB	12

/* New for 0.4-pre7 (David Olofson) */
#define	SOUND_LAUNCH	13
#define	SOUND_LAUNCH2	14

#define SOUND_DEMOSONG	126
#define SOUND_DEMOSONG2	127
#define SOUND_LAST_DEMOSONG	127
